@@ -53,6 +53,8 @@ class GridFSStore(Store):
         compression: bool = False,
         ensure_metadata: bool = False,
         searchable_fields: List[str] = None,
+        auth_source: Optional[str] = None,
+        mongoclient_kwargs: Optional[Dict] = None,
         **kwargs,
     ):
         """
@@ -68,6 +70,7 @@ class GridFSStore(Store):
             compression: compress the data as it goes into GridFS
             ensure_metadata: ensure returned documents have the metadata fields
             searchable_fields: fields to keep in the index store
+            auth_source: The database to authenticate on. Defaults to the database name.
         """
 
         self.database = database
@@ -82,6 +85,11 @@ class GridFSStore(Store):
         self.searchable_fields = [] if searchable_fields is None else searchable_fields
         self.kwargs = kwargs
 
+        if auth_source is None:
+            auth_source = self.database
+        self.auth_source = auth_source
+        self.mongoclient_kwargs = mongoclient_kwargs or {}
+
         if "key" not in kwargs:
             kwargs["key"] = "_id"
         super().__init__(**kwargs)
@@ -124,9 +132,11 @@ class GridFSStore(Store):
                 port=self.port,
                 username=self.username,
                 password=self.password,
+                authSource=self.auth_source,
+                **self.mongoclient_kwargs,
             )
             if self.username != ""
-            else MongoClient(self.host, self.port)
+            else MongoClient(self.host, self.port, **self.mongoclient_kwargs)
         )
         if not self._coll or force_reset:
             db = conn[self.database]
@@ -228,7 +238,10 @@ class GridFSStore(Store):
                 metadata = doc.get("metadata", {})
 
                 data = self._collection.find_one(
-                    filter={"_id": doc["_id"]}, skip=skip, limit=limit, sort=sort,
+                    filter={"_id": doc["_id"]},
+                    skip=skip,
+                    limit=limit,
+                    sort=sort,
                 ).read()
 
                 if metadata.get("compression", "") == "zlib":
@@ -496,7 +509,7 @@ class GridFSURIStore(GridFSStore):
         Connect to the source data
         """
         if not self._coll or force_reset:  # pragma: no cover
-            conn = MongoClient(self.uri)
+            conn = MongoClient(self.uri, **self.mongoclient_kwargs)
             db = conn[self.database]
             self._coll = gridfs.GridFS(db, self.collection_name)
             self._files_collection = db["{}.files".format(self.collection_name)]
