@@ -121,6 +121,8 @@ class MongoStore(Store):
         password: str = "",
         ssh_tunnel: Optional[SSHTunnel] = None,
         safe_update: bool = False,
+        auth_source: Optional[str] = None,
+        mongoclient_kwargs: Optional[Dict] = None,
         **kwargs,
     ):
         """
@@ -132,6 +134,7 @@ class MongoStore(Store):
             username: Username for the collection
             password: Password to connect with
             safe_update: fail gracefully on DocumentTooLarge errors on update
+            auth_source: The database to authenticate on. Defaults to the database name.
         """
         self.database = database
         self.collection_name = collection_name
@@ -143,6 +146,12 @@ class MongoStore(Store):
         self.safe_update = safe_update
         self._coll = None  # type: Any
         self.kwargs = kwargs
+
+        if auth_source is None:
+            auth_source = self.database
+        self.auth_source = auth_source
+        self.mongoclient_kwargs = mongoclient_kwargs or {}
+
         super().__init__(**kwargs)
 
     @property
@@ -170,10 +179,11 @@ class MongoStore(Store):
                     port=port,
                     username=self.username,
                     password=self.password,
-                    authSource=self.database,
+                    authSource=self.auth_source,
+                    **self.mongoclient_kwargs,
                 )
                 if self.username != ""
-                else MongoClient(host, port)
+                else MongoClient(host, port, **self.mongoclient_kwargs)
             )
             db = conn[self.database]
             self._coll = db[self.collection_name]
@@ -557,7 +567,7 @@ class MongoURIStore(MongoStore):
         Connect to the source data
         """
         if self._coll is None or force_reset:  # pragma: no cover
-            conn = MongoClient(self.uri)
+            conn = MongoClient(self.uri, **self.mongoclient_kwargs)
             db = conn[self.database]
             self._coll = db[self.collection_name]
 
